@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_elb.paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from mypy_boto3_elb.type_defs import (
@@ -58,29 +58,29 @@ __all__ = ("ElasticLoadBalancingClient",)
 
 
 class Exceptions:
-    AccessPointNotFoundException: Boto3ClientError
-    CertificateNotFoundException: Boto3ClientError
-    ClientError: Boto3ClientError
-    DependencyThrottleException: Boto3ClientError
-    DuplicateAccessPointNameException: Boto3ClientError
-    DuplicateListenerException: Boto3ClientError
-    DuplicatePolicyNameException: Boto3ClientError
-    DuplicateTagKeysException: Boto3ClientError
-    InvalidConfigurationRequestException: Boto3ClientError
-    InvalidEndPointException: Boto3ClientError
-    InvalidSchemeException: Boto3ClientError
-    InvalidSecurityGroupException: Boto3ClientError
-    InvalidSubnetException: Boto3ClientError
-    ListenerNotFoundException: Boto3ClientError
-    LoadBalancerAttributeNotFoundException: Boto3ClientError
-    OperationNotPermittedException: Boto3ClientError
-    PolicyNotFoundException: Boto3ClientError
-    PolicyTypeNotFoundException: Boto3ClientError
-    SubnetNotFoundException: Boto3ClientError
-    TooManyAccessPointsException: Boto3ClientError
-    TooManyPoliciesException: Boto3ClientError
-    TooManyTagsException: Boto3ClientError
-    UnsupportedProtocolException: Boto3ClientError
+    AccessPointNotFoundException: Type[Boto3ClientError]
+    CertificateNotFoundException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    DependencyThrottleException: Type[Boto3ClientError]
+    DuplicateAccessPointNameException: Type[Boto3ClientError]
+    DuplicateListenerException: Type[Boto3ClientError]
+    DuplicatePolicyNameException: Type[Boto3ClientError]
+    DuplicateTagKeysException: Type[Boto3ClientError]
+    InvalidConfigurationRequestException: Type[Boto3ClientError]
+    InvalidEndPointException: Type[Boto3ClientError]
+    InvalidSchemeException: Type[Boto3ClientError]
+    InvalidSecurityGroupException: Type[Boto3ClientError]
+    InvalidSubnetException: Type[Boto3ClientError]
+    ListenerNotFoundException: Type[Boto3ClientError]
+    LoadBalancerAttributeNotFoundException: Type[Boto3ClientError]
+    OperationNotPermittedException: Type[Boto3ClientError]
+    PolicyNotFoundException: Type[Boto3ClientError]
+    PolicyTypeNotFoundException: Type[Boto3ClientError]
+    SubnetNotFoundException: Type[Boto3ClientError]
+    TooManyAccessPointsException: Type[Boto3ClientError]
+    TooManyPoliciesException: Type[Boto3ClientError]
+    TooManyTagsException: Type[Boto3ClientError]
+    UnsupportedProtocolException: Type[Boto3ClientError]
 
 
 class ElasticLoadBalancingClient:
